mercurial/commands.py
changeset 2135 11ad47f22023
parent 2134 ef81e34ad674
child 2140 6447a32aefce
--- a/mercurial/commands.py	Wed Apr 26 10:57:40 2006 -0700
+++ b/mercurial/commands.py	Wed Apr 26 12:05:16 2006 -0700
@@ -1572,10 +1572,15 @@
         doexport(ui, repo, cset, seqno, total, revwidth, opts)
 
 def forget(ui, repo, *pats, **opts):
-    """don't add the specified files on the next commit
-
+    """don't add the specified files on the next commit (DEPRECATED)
+
+    (DEPRECATED)
     Undo an 'hg add' scheduled for the next commit.
+
+    This command is now deprecated and will be removed in a future
+    release. Please use revert instead.
     """
+    ui.warn(_("(the forget command is deprecated; use revert instead)\n"))
     forget = []
     for src, abs, rel, exact in walk(repo, pats, opts):
         if repo.dirstate.state(abs) == 'a':